@@ -19,14 +19,15 @@ def transactional(func):
         if session_context.session is None:
             session_context.session = _create_session()
             try:
-                func(*args)
+                func_response = func(*args)
                 session_context.session.commit()
+                return func_response
             except Exception as e:
                 session_context.session.rollback()
                 raise e
             finally:
                 session_context.session.close()
         else:
-            func(*args)
+            return func(*args)
 
     return wrapper
